@@ -47,11 +47,11 @@
 
 #include "snd-strings.h"
 
-#define SND_DATE "10-Oct-24"
+#define SND_DATE "17-Nov-24"
 #ifndef SND_VERSION
-#define SND_VERSION "24.8"
+#define SND_VERSION "24.9"
 #endif
 #define SND_MAJOR_VERSION "24"
-#define SND_MINOR_VERSION "8"
+#define SND_MINOR_VERSION "9"
 
 #endif
