@@ -285,6 +285,9 @@
 (format *stderr* "~NC tlimit ~NC~%" 20 #\- 20 #\-)
 (system "./repl tlimit.scm")
 
+(format *stderr* "~NC tbit ~NC~%" 20 #\- 20 #\-)
+(system "./repl tbit.scm")
+
 (format *stderr* "~NC index ~NC~%" 20 #\- 20 #\-)
 (system "./snd make-index.scm")
 
@@ -303,9 +306,10 @@
 (format *stderr* "~NC full s7test ~NC~%" 20 #\- 20 #\-)
 (system "./repl full-s7test.scm")
 
-(format *stderr* "~NC full s7test ~NC~%" 20 #\- 20 #\-)
-(system "gcc -o trepl ~/cl/trepl.c s7.o -O -Wl,-export-dynamic -lm -I. -ldl")
-(system "trepl")
+(unless (provided? 'debugging) ; somehow the debugging stuff clobbers this sometimes in gdb??
+  (format *stderr* "~NC trepl full s7test ~NC~%" 20 #\- 20 #\-)
+  (system "gcc -o trepl ~/cl/trepl.c s7.o -O -Wl,-export-dynamic -lm -I. -ldl")
+  (system "trepl"))
 
 (format *stderr* "~NC valgrind leak check ~NC~%" 20 #\- 20 #\-)
 (system "valgrind --leak-check=full --show-reachable=no --suppressions=/home/bil/cl/free.supp ./repl s7test.scm")
